############################################################
#
# Functions Script
#
# Author: Stefan Nikolaus
# Source: www.nikolaus-lueneburg.de
#
############################################################

function CreatePasswordFile ($FilePath)
{
    if (Test-Path $FilePath)
    {
        Write-Host "Password file allready exist" -ForegroundColor Green
    }
    else
    {
        Try
        {
            Read-Host -assecurestring | ConvertFrom-SecureString | Out-File (Join-Path $FilePath)
        }
        Catch
        {
          Write-Host $_.Exception.Message
          break
        }
        Write-Host "Writing password file to" $FilePath -ForegroundColor Green
    }
}

function CreateCredentialObject ($FilePath, $Username)
{
    if (Test-Path $FilePath)
    {
        # Load Password File
        $Password = cat $FilePath | ConvertTo-SecureString

        # Create Credential Object
        Write-Host "Creating credential object" -ForegroundColor Green
        $Cred = New-Object -typename System.Management.Automation.PSCredential -ArgumentList $Username, $Password
        Return $Cred
    }
    else
    {
        Write-Host "Password file allready exist" -ForegroundColor Red
    }
}

function Log($text,$severity)
{
    $Time = Get-Date –f [yyyy-MM-dd_HHmmss]
    switch ($severity)
    {
        0 {
            Write-Host $text -ForegroundColor green
            "[INF] " + $time + " " + $text | Out-File -Append $Logfile
        }

        1 {
            $Global:BackupError = $true
            Write-Host $text -ForegroundColor Yellow
            "[WAR] " + $time + " " + $text | Out-File -Append $Logfile
        }

        2 {
            $Global:BackupError = $true
            Write-Host $text -ForegroundColor Red
            "[ERR] " + $time + " " + $text | Out-File -Append $Logfile
        }

        default {
            Write-Host $text
            "[---] " + $time + " " + $text | Out-File -Append $Logfile
        }
    }
}

function Mail($body,$attachments)
{
    if ($attachments)
    {
        Send-MailMessage -SmtpServer $SmtpServer -From $FromAddress -To $ToAddress -Subject $Subject -Body $body -BodyAsHtml -Attachments $attachments
    }
    else
    {
        Send-MailMessage -SmtpServer $SmtpServer -From $FromAddress -To $ToAddress -Subject $Subject -Body $body -BodyAsHtml
    }
}
